'use strict';

var path = require('path');
var yargs = require('yargs');
var glob = require('glob');
var chalk = require('chalk');
var index = require('./index.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n["default"] = e;
  return Object.freeze(n);
}

var yargs__default = /*#__PURE__*/_interopDefaultLegacy(yargs);
var glob__namespace = /*#__PURE__*/_interopNamespace(glob);
var chalk__default = /*#__PURE__*/_interopDefaultLegacy(chalk);

/* eslint no-console: off */
const argv = yargs__default["default"].usage('Usage: $0 <fixtures> [options]').option('cwd', {
  required: false,
  default: process.cwd(),
  normalize: true,
  type: 'string',
  describe: 'Working directory where the .graphqlconfig is located'
}).option('show-passes', {
  type: 'boolean',
  default: false,
  describe: 'Display passing fixtures along with failures in the console output'
}).help().argv;
index.evaluateFixtures(glob__namespace.sync(argv._[0]), {
  cwd: argv.cwd
}).then(evaluations => {
  let passed = 0;
  let failed = 0;
  let lastFailed = false;
  console.log();
  evaluations.forEach(evaluation => {
    const relativePath = path.relative(argv.cwd, evaluation.fixturePath);
    const formattedPath = `${chalk__default["default"].dim(relativePath.replace(path.basename(relativePath), ''))}${chalk__default["default"].bold(path.basename(relativePath))}`;
    if (evaluation.scriptError) {
      failed += 1;
      lastFailed = true;
      console.log(`${chalk__default["default"].inverse.bold.red(' FAIL ')} ${formattedPath}`);
      console.log(evaluation.scriptError.message);
      if (evaluation.scriptError.stack) {
        console.log(chalk__default["default"].dim(evaluation.scriptError.stack.replace(evaluation.scriptError.message, '').replace(/^Error:\s*\n/, '')));
      }
      console.log();
    } else if (evaluation.validationErrors.length === 0) {
      passed += 1;
      lastFailed = false;
      if (argv.showPasses) {
        console.log(`${chalk__default["default"].inverse.bold.green(' PASS ')} ${formattedPath}`);
      }
    } else {
      failed += 1;
      lastFailed = true;
      console.log(`${chalk__default["default"].inverse.bold.red(' FAIL ')} ${formattedPath}`);
      evaluation.validationErrors.forEach(error => {
        console.log(`${error.keyPath} ${chalk__default["default"].red(error.message)}`);
      });
      console.log();
    }
  });
  if (passed + failed === 0) {
    console.log(chalk__default["default"].bold.yellow('No tests run'));
    return;
  }
  if (!lastFailed) {
    console.log();
  }
  if (passed > 0) {
    console.log(chalk__default["default"].bold.green(`${passed} passed`));
  }
  if (failed > 0) {
    console.log(chalk__default["default"].bold.red(`${failed} failed`));
    process.exit(1);
  }
}).catch(error => {
  console.log();
  console.log(`${chalk__default["default"].inverse.bold.red(' ERROR ')} ${error.message}`);
  console.log(chalk__default["default"].dim(error.stack.replace(error.message, '').replace(/^Error:\s*\n/, '')));
  process.exit(1);
});
